# coding: utf-8

"""
    

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: beta
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat

from six import iteritems


class ModelTrainingPK(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'model_ref': 'ModelRef',
        'process_lineage_ref': 'ProcessLineageRef'
    }

    attribute_map = {
        'model_ref': 'modelRef',
        'process_lineage_ref': 'processLineageRef'
    }

    def __init__(self, model_ref=None, process_lineage_ref=None):
        """
        ModelTrainingPK - a model defined in Swagger
        """

        self._model_ref = None
        self._process_lineage_ref = None

        self.model_ref = model_ref
        self.process_lineage_ref = process_lineage_ref

    @property
    def model_ref(self):
        """
        Gets the model_ref of this ModelTrainingPK.
        The trained model

        :return: The model_ref of this ModelTrainingPK.
        :rtype: ModelRef
        """
        return self._model_ref

    @model_ref.setter
    def model_ref(self, model_ref):
        """
        Sets the model_ref of this ModelTrainingPK.
        The trained model

        :param model_ref: The model_ref of this ModelTrainingPK.
        :type: ModelRef
        """
        if model_ref is None:
            raise ValueError("Invalid value for `model_ref`, must not be `None`")

        self._model_ref = model_ref

    @property
    def process_lineage_ref(self):
        """
        Gets the process_lineage_ref of this ModelTrainingPK.
        The lineage that contains the training process

        :return: The process_lineage_ref of this ModelTrainingPK.
        :rtype: ProcessLineageRef
        """
        return self._process_lineage_ref

    @process_lineage_ref.setter
    def process_lineage_ref(self, process_lineage_ref):
        """
        Sets the process_lineage_ref of this ModelTrainingPK.
        The lineage that contains the training process

        :param process_lineage_ref: The process_lineage_ref of this ModelTrainingPK.
        :type: ProcessLineageRef
        """
        if process_lineage_ref is None:
            raise ValueError("Invalid value for `process_lineage_ref`, must not be `None`")

        self._process_lineage_ref = process_lineage_ref

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelTrainingPK):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
